@@ -153,10 +153,6 @@ QIcon MainWindow::find_icon(const QString &icon_name)
     QString name_no_ext = icon_name;
     name_no_ext.remove(re);
 
-    if (!icon_theme.isEmpty()) {
-        QIcon::setThemeName(icon_theme);
-    }
-
     QIcon icon = QIcon::fromTheme(name_no_ext);
     if (!icon.isNull()) {
         icon_cache[icon_name] = icon;
@@ -250,7 +246,11 @@ void MainWindow::set_gui()
 
 void MainWindow::btn_clicked()
 {
-    const QString cmd = sender()->property("cmd").toString();
+    const auto *button = sender();
+    if (!button) {
+        return;
+    }
+    const QString cmd = button->property("cmd").toString();
     if (cmd.trimmed().isEmpty()) {
         QMessageBox::warning(this, tr("Execution Error"), tr("Command is empty. Cannot execute."));
         return;
@@ -265,13 +265,17 @@ void MainWindow::btn_clicked()
         QProcess proc;
         proc.start("/bin/sh", {"-c", cmd});
 
-        // Wait for process to finish while keeping event loop responsive
-        while (!proc.waitForFinished(100)) {
-            QApplication::processEvents();
-        }
+        if (!proc.waitForStarted()) {
+            QMessageBox::warning(this, tr("Execution Error"), tr("Failed to start command: %1").arg(cmd));
+        } else {
+            // Wait for process to finish while keeping event loop responsive
+            while (!proc.waitForFinished(100)) {
+                QApplication::processEvents();
+            }
 
-        if (proc.exitCode() != 0) {
-            QMessageBox::warning(this, tr("Execution Error"), tr("Failed to execute command: %1").arg(cmd));
+            if (proc.exitCode() != 0) {
+                QMessageBox::warning(this, tr("Execution Error"), tr("Failed to execute command: %1").arg(cmd));
+            }
         }
 
         if (hide_gui) {
@@ -286,13 +290,17 @@ void MainWindow::btn_clicked()
         const QString program = arguments.takeFirst();
         proc.start(program, arguments);
 
-        // Wait for process to finish while keeping event loop responsive
-        while (!proc.waitForFinished(100)) {
-            QApplication::processEvents();
-        }
+        if (!proc.waitForStarted()) {
+            QMessageBox::warning(this, tr("Execution Error"), tr("Failed to start program: %1").arg(program));
+        } else {
+            // Wait for process to finish while keeping event loop responsive
+            while (!proc.waitForFinished(100)) {
+                QApplication::processEvents();
+            }
 
-        if (proc.exitCode() != 0) {
-            QMessageBox::warning(this, tr("Execution Error"), tr("Failed to execute command: %1").arg(cmd));
+            if (proc.exitCode() != 0) {
+                QMessageBox::warning(this, tr("Execution Error"), tr("Failed to execute command: %1").arg(cmd));
+            }
         }
 
         show();
@@ -321,7 +329,7 @@ void MainWindow::resizeEvent(QResizeEvent *event)
     }
 
     const int item_size = 200; // Determined through trial and error
-    const int new_count = width() / item_size;
+    const int new_count = qMax(1, width() / item_size);
 
     if (new_count == col_count) {
         return;
@@ -419,9 +427,11 @@ MainWindow::ItemInfo MainWindow::get_desktop_file_info(const QString &file_name)
     file.close();
 
     // Helper lambda to search for a pattern and extract the first capture group
-    auto match_pattern = [&text](const QString &pattern) -> QString {
-        QRegularExpression re(pattern, QRegularExpression::MultilineOption);
-        const auto match = re.match(text);
+    auto match_pattern = [this, &text](const QString &pattern) -> QString {
+        if (!regex_cache.contains(pattern)) {
+            regex_cache[pattern] = QRegularExpression(pattern, QRegularExpression::MultilineOption);
+        }
+        const auto match = regex_cache[pattern].match(text);
         return match.hasMatch() ? match.captured(1) : QString();
     };
 
@@ -454,17 +464,26 @@ void MainWindow::add_buttons(const QMultiMap<QString, ItemInfo> &map)
     clear_grid_layout();
     int col = 0;
     int row = 0;
-    const int max_cols = fixed_number_col != 0 ? fixed_number_col : width() / 200;
+    const int max_cols = fixed_number_col != 0 ? fixed_number_col : qMax(1, width() / 200);
 
-    for (const auto &category : map.uniqueKeys()) {
-        if (!map.values(category).isEmpty()) {
-            add_category_label(category, row, col);
+    QString prev_category;
+    for (auto it = map.constBegin(); it != map.constEnd();) {
+        const QString &category = it.key();
 
-            for (const auto &item : map.values(category)) {
-                add_item_button(item, row, col, max_cols);
+        // Add category label on first encounter
+        if (category != prev_category) {
+            if (!prev_category.isEmpty()) {
+                add_empty_row_if_needed(prev_category, map, row, col);
             }
+            add_category_label(category, row, col);
+            prev_category = category;
         }
-        add_empty_row_if_needed(category, map, row, col);
+
+        add_item_button(it.value(), row, col, max_cols);
+        ++it;
+    }
+    if (!prev_category.isEmpty()) {
+        add_empty_row_if_needed(prev_category, map, row, col);
     }
     ui->gridLayout_btn->setRowStretch(row, 1);
 }
@@ -608,6 +627,7 @@ void MainWindow::read_file(const QString &file_name)
     categories.reserve(20); // Reserve space for typical number of categories
     category_map.clear();
     icon_theme.clear();
+    desktop_file_cache.clear();
 
     QFile file(file_name);
     if (!file.exists()) {
@@ -654,6 +674,10 @@ void MainWindow::read_file(const QString &file_name)
 
         pos = endPos + 1;
     }
+
+    if (!icon_theme.isEmpty()) {
+        QIcon::setThemeName(icon_theme);
+    }
 }
 
 QString MainWindow::extract_pattern(const QString &text, const QString &key)
@@ -839,7 +863,7 @@ QString MainWindow::get_default_editor()
         if (line.startsWith("Exec=")) {
             // Extract the command from the Exec line and remove common desktop file parameters
             static const QRegularExpression execPrefixPattern("^Exec=");
-            static const QRegularExpression paramPattern("(%[a-zA-Z]|%[a-zA-Z]{1,2}|-{1,2}[a-zA-Z-]+)\\b");
+            static const QRegularExpression paramPattern(" %[a-zA-Z]");
             return line.remove(execPrefixPattern).remove(paramPattern).trimmed();
         }
     }
@@ -850,8 +874,8 @@ QString MainWindow::get_default_editor()
 QStringList MainWindow::build_editor_command(const QString &editor)
 {
     const bool is_root = getuid() == 0;
-    static const QRegularExpression elevates_pattern(R"((kate|kwrite|featherpad|code|codium)$)");
-    static const QRegularExpression cli_pattern(R"(nano|vi|vim|nvim|micro|emacs)");
+    static const QRegularExpression elevates_pattern(R"(\b(kate|kwrite|featherpad|code|codium)$)");
+    static const QRegularExpression cli_pattern(R"(\b(nano|vi|vim|nvim|micro|emacs)\b)");
     const bool is_editor_that_elevates = elevates_pattern.match(editor).hasMatch();
     const bool is_cli_editor = cli_pattern.match(editor).hasMatch();
 
